@@ -12,12 +12,16 @@ where
     K: ToString + FromStr + Eq + Hash + Sync + Send,
     V: Type,
 {
+    const IS_REQUIRED: bool = true;
+
+    type RawValueType = Self;
+
+    type RawElementValueType = V::RawValueType;
+
     fn name() -> Cow<'static, str> {
         "object".into()
     }
 
-    impl_raw_value_type!();
-
     fn schema_ref() -> MetaSchemaRef {
         MetaSchemaRef::Inline(Box::new(MetaSchema {
             additional_properties: Some(Box::new(V::schema_ref())),
@@ -28,6 +32,16 @@ where
     fn register(registry: &mut Registry) {
         V::register(registry);
     }
+
+    fn as_raw_value(&self) -> Option<&Self::RawValueType> {
+        Some(self)
+    }
+
+    fn raw_element_iter<'a>(
+        &'a self,
+    ) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a> {
+        Box::new(self.values().map(|item| item.as_raw_value()).flatten())
+    }
 }
 
 impl<K, V> ParseFromJSON for HashMap<K, V>
